// src/use-chip.ts
import { mapPropsVariants } from "@nextui-org/system";
import { mergeProps } from "@react-aria/utils";
import { usePress } from "@react-aria/interactions";
import { useFocusRing } from "@react-aria/focus";
import { chip } from "@nextui-org/theme";
import { useDOMRef } from "@nextui-org/dom-utils";
import { clsx } from "@nextui-org/shared-utils";
import { useMemo, isValidElement, cloneElement } from "react";
function useChip(originalProps) {
  const [props, variantProps] = mapPropsVariants(originalProps, chip.variantKeys);
  const {
    ref,
    as,
    children,
    avatar,
    leftContent,
    rightContent,
    onClose,
    styles,
    className,
    ...otherProps
  } = props;
  const Component = as || "div";
  const domRef = useDOMRef(ref);
  const baseStyles = clsx(styles == null ? void 0 : styles.base, className);
  const isCloseable = !!onClose;
  const isDotVariant = originalProps.variant === "dot";
  const { focusProps: closeFocusProps, isFocusVisible: isCloseButtonFocusVisible } = useFocusRing();
  const isOneChar = useMemo(
    () => typeof children === "string" && (children == null ? void 0 : children.length) === 1,
    [children]
  );
  const hasLeftContent = useMemo(() => !!avatar || !!leftContent, [avatar, leftContent]);
  const hasRightContent = useMemo(() => !!rightContent || isCloseable, [rightContent, isCloseable]);
  const slots = useMemo(
    () => chip({
      ...variantProps,
      hasLeftContent,
      hasRightContent,
      isOneChar,
      isCloseButtonFocusVisible
    }),
    [
      ...Object.values(variantProps),
      isCloseButtonFocusVisible,
      hasLeftContent,
      hasRightContent,
      isOneChar
    ]
  );
  const { pressProps: closePressProps } = usePress({
    isDisabled: !!(originalProps == null ? void 0 : originalProps.isDisabled),
    onPress: onClose
  });
  const getChipProps = () => {
    return {
      ref: domRef,
      className: slots.base({ class: baseStyles }),
      ...otherProps
    };
  };
  const getCloseButtonProps = () => {
    return {
      role: "button",
      tabIndex: 0,
      className: slots.closeButton({ class: styles == null ? void 0 : styles.closeButton }),
      ...mergeProps(closePressProps, closeFocusProps)
    };
  };
  const getAvatarClone = (avatar2) => {
    if (!isValidElement(avatar2))
      return null;
    return cloneElement(avatar2, {
      className: slots.avatar({ class: styles == null ? void 0 : styles.avatar })
    });
  };
  const getContentClone = (content) => isValidElement(content) ? cloneElement(content, {
    className: clsx("max-h-[80%]", content.props.className)
  }) : null;
  return {
    Component,
    children,
    slots,
    styles,
    isDot: isDotVariant,
    isCloseable,
    leftContent: getAvatarClone(avatar) || getContentClone(leftContent),
    rightContent: getContentClone(rightContent),
    getCloseButtonProps,
    getChipProps
  };
}

export {
  useChip
};
