"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  Chip: () => chip_default,
  useChip: () => useChip
});
module.exports = __toCommonJS(src_exports);

// src/use-chip.ts
var import_system = require("@nextui-org/system");
var import_utils = require("@react-aria/utils");
var import_interactions = require("@react-aria/interactions");
var import_focus = require("@react-aria/focus");
var import_theme = require("@nextui-org/theme");
var import_dom_utils = require("@nextui-org/dom-utils");
var import_shared_utils = require("@nextui-org/shared-utils");
var import_react = require("react");
function useChip(originalProps) {
  const [props, variantProps] = (0, import_system.mapPropsVariants)(originalProps, import_theme.chip.variantKeys);
  const {
    ref,
    as,
    children,
    avatar,
    leftContent,
    rightContent,
    onClose,
    styles,
    className,
    ...otherProps
  } = props;
  const Component = as || "div";
  const domRef = (0, import_dom_utils.useDOMRef)(ref);
  const baseStyles = (0, import_shared_utils.clsx)(styles == null ? void 0 : styles.base, className);
  const isCloseable = !!onClose;
  const isDotVariant = originalProps.variant === "dot";
  const { focusProps: closeFocusProps, isFocusVisible: isCloseButtonFocusVisible } = (0, import_focus.useFocusRing)();
  const isOneChar = (0, import_react.useMemo)(
    () => typeof children === "string" && (children == null ? void 0 : children.length) === 1,
    [children]
  );
  const hasLeftContent = (0, import_react.useMemo)(() => !!avatar || !!leftContent, [avatar, leftContent]);
  const hasRightContent = (0, import_react.useMemo)(() => !!rightContent || isCloseable, [rightContent, isCloseable]);
  const slots = (0, import_react.useMemo)(
    () => (0, import_theme.chip)({
      ...variantProps,
      hasLeftContent,
      hasRightContent,
      isOneChar,
      isCloseButtonFocusVisible
    }),
    [
      ...Object.values(variantProps),
      isCloseButtonFocusVisible,
      hasLeftContent,
      hasRightContent,
      isOneChar
    ]
  );
  const { pressProps: closePressProps } = (0, import_interactions.usePress)({
    isDisabled: !!(originalProps == null ? void 0 : originalProps.isDisabled),
    onPress: onClose
  });
  const getChipProps = () => {
    return {
      ref: domRef,
      className: slots.base({ class: baseStyles }),
      ...otherProps
    };
  };
  const getCloseButtonProps = () => {
    return {
      role: "button",
      tabIndex: 0,
      className: slots.closeButton({ class: styles == null ? void 0 : styles.closeButton }),
      ...(0, import_utils.mergeProps)(closePressProps, closeFocusProps)
    };
  };
  const getAvatarClone = (avatar2) => {
    if (!(0, import_react.isValidElement)(avatar2))
      return null;
    return (0, import_react.cloneElement)(avatar2, {
      className: slots.avatar({ class: styles == null ? void 0 : styles.avatar })
    });
  };
  const getContentClone = (content) => (0, import_react.isValidElement)(content) ? (0, import_react.cloneElement)(content, {
    className: (0, import_shared_utils.clsx)("max-h-[80%]", content.props.className)
  }) : null;
  return {
    Component,
    children,
    slots,
    styles,
    isDot: isDotVariant,
    isCloseable,
    leftContent: getAvatarClone(avatar) || getContentClone(leftContent),
    rightContent: getContentClone(rightContent),
    getCloseButtonProps,
    getChipProps
  };
}

// src/chip.tsx
var import_system2 = require("@nextui-org/system");
var import_shared_icons = require("@nextui-org/shared-icons");
var import_react2 = require("react");
var import_jsx_runtime = require("react/jsx-runtime");
var Chip = (0, import_system2.forwardRef)((props, ref) => {
  const {
    Component,
    children,
    slots,
    styles,
    isDot,
    isCloseable,
    leftContent,
    rightContent,
    getCloseButtonProps,
    getChipProps
  } = useChip({
    ref,
    ...props
  });
  const left = (0, import_react2.useMemo)(() => {
    if (isDot && !leftContent) {
      return /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { className: slots.dot({ class: styles == null ? void 0 : styles.dot }) });
    }
    return leftContent;
  }, [slots, leftContent, isDot]);
  const right = (0, import_react2.useMemo)(() => {
    if (isCloseable) {
      return /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { ...getCloseButtonProps(), children: !rightContent ? /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_shared_icons.CloseFilledIcon, {}) : rightContent });
    }
    return rightContent;
  }, [rightContent, isCloseable, getCloseButtonProps]);
  return /* @__PURE__ */ (0, import_jsx_runtime.jsxs)(Component, { ...getChipProps(), children: [
    left,
    /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { className: slots.content({ class: styles == null ? void 0 : styles.content }), children }),
    right
  ] });
});
Chip.displayName = "NextUI.Chip";
var chip_default = Chip;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Chip,
  useChip
});
